@@ -9,22 +9,24 @@ import shutil
 import sys
 
 from pandas import DataFrame
+from requests.exceptions import ConnectionError
+from requests.models import Response
 import dask.dataframe as dd
-import dask.distributed as dist
-import jsoncomment as jsonc
+import pyjson5 as jsonc
 import numpy as np
 import pandasql
 import requests
 import yaml
 
 from hidebound.core.config import Config
+from hidebound.core.connection import DaskConnection
+from hidebound.core.logging import ProgressLogger
 from hidebound.core.specification_base import SpecificationBase
+from hidebound.exporters.disk_exporter import DiskExporter
 from hidebound.exporters.girder_exporter import GirderExporter
-from hidebound.exporters.local_disk_exporter import LocalDiskExporter
 from hidebound.exporters.s3_exporter import S3Exporter
 import hidebound.core.database_tools as db_tools
 import hidebound.core.tools as hbt
-from hidebound.core.logging import ProgressLogger
 # ------------------------------------------------------------------------------
 
 
@@ -49,6 +51,8 @@ class Database:
         '''
         # validate config and populate with default values
         config = deepcopy(config)
+        testing = config.get('testing', False)
+        config.pop('testing', None)
         config = Config(config)
         config.validate()
         config = config.to_primitive()
@@ -76,8 +80,8 @@ class Database:
             write_mode=config['write_mode'],
             exporters=config['exporters'],
             webhooks=config['webhooks'],
-            dask_enabled=config['dask_enabled'],
             dask_workers=config['dask_workers'],
+            testing=testing,
         )
 
     @staticmethod
@@ -93,7 +97,7 @@ class Database:
             Database: Database instance.
         '''
         with open(filepath) as f:
-            config = jsonc.JsonComment().load(f)
+            config = jsonc.load(f)
         return Database.from_config(config)
 
     @staticmethod
@@ -120,10 +124,11 @@ class Database:
         include_regex='',             # type: str
         exclude_regex=r'\.DS_Store',  # type: str
         write_mode='copy',            # type: str
-        exporters={},                 # type: Dict[str, Any]
-        webhooks=[],                  # type: List[Dict]
-        dask_enabled=False,           # type: bool
+        exporters=[],                 # type: List[Dict[str, Any]]
+        webhooks=[],                  # type: List[Dict[str, Any]]
         dask_workers=8,               # type: int
+        dask_cluster_type='local',    # type: str
+        testing=False,                # type: bool
     ):
         # type: (...) -> None
         r'''
@@ -141,15 +146,16 @@ class Database:
                 regex. Default: '\.DS_Store'.
             write_mode (str, optional): How assets will be extracted to
                 hidebound/content directory. Default: copy.
-            exporters (dict, optional): Dictionary of exporter configs, where
-                the key is the exporter name and the value is its config.
-                Default: {}.
+            exporters (list[dict], optional): List of exporter configs.
+                Default: [].
             webhooks (list[dict], optional): List of webhooks to call.
                 Default: [].
-            dask_enabled (bool, optional): Whether to enable Dask.
                 Default: False.
             dask_workers (int, optional): Number of partitions to use for
                 Dask. Must be 1 or greater. Default: 8.
+            dask_cluster_type: (str, optional): Dask cluster type:
+                Default: local.
+            testing: (bool, optional): Used for testing. Default: False.
 
         Raises:
             TypeError: If specifications contains a non-SpecificationBase
@@ -207,10 +213,19 @@ class Database:
         self._write_mode = write_mode
         self._specifications = {x.__name__.lower(): x for x in specifications} \
             # type: Dict[str, SpecificationBase]
+
+        # setup exporters
+        for exp in exporters:
+            exp['dask_workers'] = exp.get('dask_workers', dask_workers)
+            exp['dask_cluster_type'] = exp.get(
+                'dask_cluster_type', dask_cluster_type
+            )
         self._exporters = exporters
+
         self._webhooks = webhooks
-        self._dask_enabled = dask_enabled
         self._dask_workers = dask_workers
+        self._dask_cluster_type = dask_cluster_type
+        self._testing = testing
         self.data = None
 
         # needed for testing
@@ -244,42 +259,63 @@ class Database:
             msg = 'Data not initialized. Please call update.'
             raise RuntimeError(msg)
 
-        temp = db_tools.get_data_for_write(
-            self.data, self._root, self._staging
-        )
+        temp = db_tools.get_data_for_write(self.data, self._root, self._staging)
         self._logger.info('create: get data', step=1, total=total)
         if temp is None:
             return self
 
+        # convert to dask dataframes
         file_data, asset_meta, file_meta, asset_chunk, file_chunk = temp
+        nparts = self._dask_workers
+        file_data = dd.from_pandas(file_data, npartitions=nparts)
+        asset_meta = dd.from_pandas(asset_meta, npartitions=nparts)
+        file_meta = dd.from_pandas(file_meta, npartitions=nparts)
+        asset_chunk = dd.from_pandas(asset_chunk, npartitions=nparts)
+        file_chunk = dd.from_pandas(file_chunk, npartitions=nparts)
+        temp = [file_data, asset_meta, file_meta, asset_chunk, file_chunk]
 
         # make directories
         for item in temp:
-            item.target.apply(lambda x: os.makedirs(Path(x).parent, exist_ok=True))
+            item.target.apply(
+                lambda x: os.makedirs(Path(x).parent, exist_ok=True),
+                meta=np.nan
+            ).compute()
         self._logger.info('create: make directories', step=2, total=total)
 
         # write file data
         if self._write_mode == 'move':
-            file_data.apply(lambda x: shutil.move(x.source, x.target), axis=1)
+            file_data.apply(
+                lambda x: shutil.move(x.source, x.target), axis=1, meta=np.nan
+            ).compute()
             hbt.delete_empty_directories(self._root)
         else:
-            file_data.apply(lambda x: shutil.copy2(x.source, x.target), axis=1)
+            file_data.apply(
+                lambda x: shutil.copy2(x.source, x.target), axis=1, meta=np.nan
+            ).compute()
         self._logger.info('create: write file data', step=3, total=total)
 
         # write asset metadata
-        asset_meta.apply(lambda x: hbt.write_json(x.metadata, x.target), axis=1)
+        asset_meta.apply(
+            lambda x: hbt.write_json(x.metadata, x.target), axis=1, meta=np.nan
+        ).compute()
         self._logger.info('create: write asset metadata', step=4, total=total)
 
         # write file metadata
-        file_meta.apply(lambda x: hbt.write_json(x.metadata, x.target), axis=1)
+        file_meta.apply(
+            lambda x: hbt.write_json(x.metadata, x.target), axis=1, meta=np.nan
+        ).compute()
         self._logger.info('create: write file metadata', step=5, total=total)
 
         # write asset chunk
-        asset_chunk.apply(lambda x: hbt.write_json(x.metadata, x.target), axis=1)
+        asset_chunk.apply(
+            lambda x: hbt.write_json(x.metadata, x.target), axis=1, meta=np.nan
+        ).compute()
         self._logger.info('create: write asset chunk', step=6, total=total)
 
         # write file chunk
-        file_chunk.apply(lambda x: hbt.write_json(x.metadata, x.target), axis=1)
+        file_chunk.apply(
+            lambda x: hbt.write_json(x.metadata, x.target), axis=1, meta=np.nan
+        ).compute()
         self._logger.info('create: write file chunk', step=7, total=total)
 
         self._logger.info('create: complete', step=7, total=total)
@@ -395,29 +431,25 @@ class Database:
         self._logger.info(f'update: parsed {self._root}', step=1, total=total)
 
         if len(data) > 0:
-            if self._dask_enabled:
-                cluster = dist.LocalCluster(n_workers=self._dask_workers)
-                dist.Client(cluster)
+            with DaskConnection(self._dask_cluster_type, self._dask_workers):
                 data = dd.from_pandas(data, npartitions=self._dask_workers)
-
-            data = db_tools.add_specification(data, self._specifications)
-            data = db_tools.validate_filepath(data)
-            data = db_tools.add_file_traits(data)
-            data = db_tools.add_relative_path(data, 'filepath', self._root)
-            data = db_tools.add_asset_name(data)
-            data = db_tools.add_asset_path(data)
-            data = db_tools.add_relative_path(data, 'asset_path', self._root)
-            data = db_tools.add_asset_type(data)
-            data = db_tools.add_asset_traits(data)
-            data = db_tools.validate_assets(data)
-            if self._dask_enabled:
+                data = db_tools.add_specification(data, self._specifications)
+                data = db_tools.validate_filepath(data)
+                data = db_tools.add_file_traits(data)
+                data = db_tools.add_relative_path(data, 'filepath', self._root)
+                data = db_tools.add_asset_name(data)
+                data = db_tools.add_asset_path(data)
+                data = db_tools.add_relative_path(data, 'asset_path', self._root)
+                data = db_tools.add_asset_type(data)
+                data = db_tools.add_asset_traits(data)
+                data = db_tools.validate_assets(data)
                 data = data.compute()
-        self._logger.info('update: generate', step=2, total=total)
+            self._logger.info('update: generate', step=2, total=total)
 
         data = db_tools.cleanup(data)
+        self._logger.info('update: cleanup', step=3, total=total)
         self.data = data
 
-        self._logger.info('update: cleanup', step=3, total=total)
         self._logger.info('update: complete', step=3, total=total)
         return self
 
@@ -471,8 +503,20 @@ class Database:
             if 'timeout' in hook:
                 kwargs['timeout'] = hook['timeout']
 
-            method = getattr(requests, method)
-            response = method(url, headers=headers, **kwargs)
+            # test response
+            response = Response()
+            response.status_code = 200
+            response._content = b'Webhook called.'
+
+            if not self._testing:
+                method = getattr(requests, method)
+                try:
+                    response = method(url, headers=headers, **kwargs)
+                except ConnectionError as e:  # pragma: no cover
+                    response = Response()  # pragma: no cover
+                    response.status_code = 403  # pragma: no cover
+                    response._content = str(e).encode('utf-8')  # pragma: no cover
+
             self._logger.info(
                 f'call_webhooks: {url} {response.text}',
                 step=i + 1,
@@ -492,7 +536,7 @@ class Database:
         # TODO: Find a nicer pattern for injecting exporters.
         lut = dict(
             girder=GirderExporter,
-            local_disk=LocalDiskExporter,
+            disk=DiskExporter,
             s3=S3Exporter,
         )  # type: Dict[str, Any]
 
@@ -500,12 +544,9 @@ class Database:
         if self.__exporter_lut is not None:
             lut = self.__exporter_lut
 
-        # always run exporters in this order
-        order = ['local_disk', 's3', 'girder']
-        items = sorted(self._exporters.items(), key=lambda x: order.index(x[0]))
-
-        total = len(items)
-        for i, (key, config) in enumerate(items):
+        total = len(self._exporters)
+        for i, config in enumerate(self._exporters):
+            key = config['name']
             exporter = lut[key].from_config(config)
             exporter.export(self._staging, logger=self._logger)
             self._logger.info(f'export: {key}', step=i + 1, total=total)
