@@ -12,8 +12,7 @@ import shutil
 import pandas as pd
 from schematics.exceptions import DataError, ValidationError
 import dask.dataframe as dd
-import jsoncomment as jsonc
-import OpenEXR as openexr
+import pyjson5 as jsonc
 
 FilePath = Union[str, Path]
 DF = Union[pd.DataFrame, dd.DataFrame]
@@ -181,29 +180,6 @@ def to_prototype(dicts):
     return output
 
 
-def read_exr_header(fullpath):
-    # type: (FilePath) -> dict
-    '''
-    Reads an OpenEXR image file header.
-
-    Args:
-        fullpath (str or Path): Image file path.
-
-    Raises:
-        IOError: If given filepath is not an EXR file.
-
-    Returns:
-        dict: EXR header.
-    '''
-    fullpath = Path(fullpath).absolute().as_posix()
-    if not openexr.isOpenExrFile(fullpath):
-        msg = f'{fullpath} is not an EXR file.'
-        raise IOError(msg)
-
-    img = openexr.InputFile(fullpath)
-    return img.header()
-
-
 def time_string():
     # type: () -> str
     '''
@@ -248,11 +224,12 @@ def read_json(filepath):
     Returns:
         object: JSON object.
     '''
-    output = jsonc.JsonComment().loadf(filepath)
-    if output is None:
-        msg = f'No JSON data could be decoded from {filepath}. '
-        msg += 'Please remove any inline comments.'
-        raise json.JSONDecodeError(msg, '', 0)
+    with open(filepath) as f:
+        try:
+            output = jsonc.load(f)
+        except Exception as e:
+            msg = f'No JSON data could be decoded from {filepath}. {str(e)}'
+            raise json.JSONDecodeError(msg, '', 0)
     return output
 
 
