@@ -8,7 +8,8 @@ import re
 
 from pandas import DataFrame
 from pyparsing import ParseException
-from schematics.exceptions import ValidationError
+from schematics.exceptions import DataError, ValidationError
+from schematics.models import Model
 import wrapt
 
 from hidebound.core.parser import AssetNameParser
@@ -702,3 +703,53 @@ def is_http_method(method):
     if method not in methods:
         msg = f'{method} is not a legal HTTP method. Legal methods: {methods}.'
         raise ValidationError(msg)
+
+
+def is_workflow(steps):
+    # type: (List[str]) -> None
+    '''
+    Ensures given workflow steps are legal.
+    Legal workflows steps include:
+
+        * delete
+        * update
+        * create
+        * export
+
+    Args:
+        steps (list[str]): List of workflow steps:
+
+    Raises:
+        ValidationError: If method is not a legal workflow.
+    '''
+    legal = ['delete', 'update', 'create', 'export']
+    diff = sorted(list(set(steps).difference(legal)))
+    if len(diff) > 0:
+        msg = f'{diff} are not legal workflow steps. Legal steps: {legal}.'
+        raise ValidationError(msg)
+
+
+def is_one_of(item, models):
+    # type: (dict, List[Model]) -> None
+    '''
+    Validates whether given item matches at least one given model.
+
+    Args:
+        item (dict): Item to be validated.
+        models (list[Model]): List schematics Models.
+
+    Raises:
+        ValidationError: If no valid model could be found for given item.
+    '''
+    if len(models) == 0:
+        return
+
+    errors = set()
+    for model in models:
+        try:
+            model(item).validate()
+            return
+        except DataError as e:
+            errors.add(str(e))
+    error = '\n'.join(list(errors))
+    raise ValidationError(error)
