@@ -1,10 +1,13 @@
 from typing import Dict, List, Optional, Union
 
 from pathlib import Path
-from schematics import Model
-from schematics.types import ListType, StringType
 import re
 
+from schematics import Model
+from schematics.types import IntType, ListType, StringType
+import dask.dataframe as dd
+
+from hidebound.core.connection import DaskConnection
 from hidebound.core.logging import DummyLogger, ProgressLogger
 import hidebound.core.tools as hbt
 import hidebound.core.validators as vd
@@ -18,12 +21,25 @@ class ExporterConfigBase(Model):
     Attributes:
         metadata_types (list, optional): List of metadata types for export.
             Default: [asset, file, asset-chunk, file-chunk].
+        dask_workers (int, optional): Number of Dask worker to use if enabled.
+            Default: 8.
+        dask_cluster_type (str, optional): Dask cluster type. Default: local.
     '''
     metadata_types = ListType(
         StringType(validators=[vd.is_metadata_type]),
         required=True,
         default=['asset', 'file', 'asset-chunk', 'file-chunk']
     )
+    dask_workers = IntType(
+        required=False,
+        serialize_when_none=False,
+        validators=[lambda x: vd.is_gt(x, 0)]
+    )  # type: IntType
+    dask_cluster_type = StringType(
+        required=False,
+        serialize_when_none=False,
+        validators=[lambda x: vd.is_in(x, ['local'])],
+    )  # type: IntType
 
 
 class ExporterBase:
@@ -31,17 +47,27 @@ class ExporterBase:
     Abstract base class for hidebound exporters.
     '''
     def __init__(
-        self, metadata_types=['asset', 'file', 'asset-chunk', 'file-chunk']
+        self,
+        metadata_types=['asset', 'file', 'asset-chunk', 'file-chunk'],
+        dask_workers=8,
+        dask_cluster_type='local',
     ):
-        # type: (List[str]) -> None
+        # type: (List[str], int, str) -> None
         '''
         Constructs a ExporterBase instance.
 
         Args:
             metadata_types (list[st], optional). Metadata types to be exported.
                 Default: [asset, file, asset-chunk, file-chunk].
+            dask_workers (int, optional): Number of Dask worker to use if
+                enabled. Default: 8.
+            dask_cluster_type (str, optional): Dask cluster type.
+                Default: local.
         '''
         self._metadata_types = metadata_types
+        self._time = hbt.time_string()
+        self._dask_cluster_type = dask_cluster_type
+        self._dask_workers = dask_workers
 
     def _enforce_directory_structure(self, staging_dir):
         # type: (Union[str, Path]) -> None
@@ -101,7 +127,10 @@ class ExporterBase:
         # export content
         regex = f'{staging_dir}/metadata/file/'
         mask = data.filepath.apply(lambda x: re.search(regex, x)).astype(bool)
-        data[mask].filepath.apply(hbt.read_json).apply(self._export_content)
+        content = data[mask].filepath.apply(hbt.read_json)
+        with DaskConnection(self._dask_cluster_type, self._dask_workers):
+            content = dd.from_pandas(content, npartitions=self._dask_workers)
+            content.apply(self._export_content, meta=object).compute()
         logger.info('exporter: export content', step=1, total=total)
 
         # export metadata
@@ -113,9 +142,13 @@ class ExporterBase:
         }
         for i, mtype in enumerate(self._metadata_types):
             regex = f'{staging_dir}/metadata/{mtype}/'
-            mask = data.filepath.apply(lambda x: re.search(regex, x)).astype(bool)
-            data[mask].filepath.apply(hbt.read_json).apply(lut[mtype])
-            logger.info(f'exporter: export {mtype}', step=i + 1, total=total)
+            mask = data.filepath.apply(lambda x: bool(re.search(regex, x)))
+            meta = data[mask].filepath.apply(hbt.read_json)
+            with DaskConnection(self._dask_cluster_type, self._dask_workers):
+                meta = dd.from_pandas(meta, npartitions=self._dask_workers)
+                meta.apply(lut[mtype], meta=object).compute()
+
+        logger.info(f'exporter: export {mtype}', step=i + 1, total=total)
 
     def _export_content(self, metadata):
         # type: (Dict) -> None
