@@ -1,4 +1,4 @@
-from typing import List
+from typing import Any, List
 
 from io import BytesIO
 import json
@@ -8,7 +8,6 @@ from schematics.types import StringType
 import boto3 as boto
 
 from hidebound.exporters.exporter_base import ExporterBase, ExporterConfigBase
-import hidebound.core.tools as tools
 import hidebound.core.validators as vd
 # ------------------------------------------------------------------------------
 
@@ -18,11 +17,15 @@ class S3Config(ExporterConfigBase):
     A class for validating configurations supplied to S3Exporter.
 
     Attributes:
+        name (str): Name of exporter. Must be 's3'.
         access_key (str): AWS access key.
         secret_key (str): AWS secret key.
         bucket (str): AWS bucket name.
         region (str): AWS region name. Default: us-east-1.
     '''
+    name = StringType(
+        required=True, validators=[lambda x: vd.is_eq(x, 's3')]
+    )  # type: StringType
     access_key = StringType(required=True)  # type: StringType
     secret_key = StringType(required=True)  # type: StringType
     bucket = StringType(
@@ -58,8 +61,9 @@ class S3Exporter(ExporterBase):
         bucket,
         region,
         metadata_types=['asset', 'file', 'asset-chunk', 'file-chunk'],
+        **kwargs,
     ):
-        # type: (str, str, str, str, List[str]) -> None
+        # type: (str, str, str, str, List[str], Any) -> None
         '''
         Constructs a S3Exporter instances and creates a bucket with given name
         if it does not exist.
@@ -78,6 +82,7 @@ class S3Exporter(ExporterBase):
         super().__init__(metadata_types=metadata_types)
 
         config = dict(
+            name='s3',
             access_key=access_key,
             secret_key=secret_key,
             bucket=bucket,
@@ -149,10 +154,9 @@ class S3Exporter(ExporterBase):
         Args:
             metadata (list[dict]): Asset metadata.
         '''
-        now = tools.time_string()
         self._bucket.upload_fileobj(
             BytesIO(json.dumps(metadata).encode('utf-8')),
-            f'hidebound/metadata/asset-chunk/hidebound-asset-chunk_{now}.json',
+            f'hidebound/metadata/asset-chunk/hidebound-asset-chunk_{self._time}.json',
         )
 
     def _export_file_chunk(self, metadata):
@@ -164,8 +168,7 @@ class S3Exporter(ExporterBase):
         Args:
             metadata (list[dict]): File metadata.
         '''
-        now = tools.time_string()
         self._bucket.upload_fileobj(
             BytesIO(json.dumps(metadata).encode('utf-8')),
-            f'hidebound/metadata/file-chunk/hidebound-file-chunk_{now}.json',
+            f'hidebound/metadata/file-chunk/hidebound-file-chunk_{self._time}.json',
         )
