@@ -2,7 +2,7 @@ from typing import Any, Dict, List, Tuple, Union
 
 import os
 
-from dash import dash_table, dcc, html
+from dash import dash_table, dcc
 from dash.dependencies import Input, Output, State
 from dash.exceptions import PreventUpdate
 import dash
@@ -10,7 +10,6 @@ import flask
 from flask import current_app
 import flask_monitoringdashboard as fmdb
 
-from hidebound.core.config import Config
 import hidebound.core.tools as hbt
 import hidebound.server.components as components
 import hidebound.server.extensions as ext
@@ -23,7 +22,7 @@ if __name__ == '__main__':
 
 # setup directories in /tmp/mnt
 if hbt.str_to_bool(os.environ.get('CREATE_TMP_DIRS', 'False')):
-    hst.setup_hidebound_directories('/tmp/mnt')
+    hst.setup_hidebound_directories('/tmp/mnt')  # pragma: no cover
 # ------------------------------------------------------------------------------
 
 
@@ -108,7 +107,7 @@ def serve_stylesheet(stylesheet):
 @APP.callback(
     output=Output('store', 'data'),
     inputs=[
-        Input('init-button', 'n_clicks'),
+        Input('workflow-button', 'n_clicks'),
         Input('update-button', 'n_clicks'),
         Input('create-button', 'n_clicks'),
         Input('export-button', 'n_clicks'),
@@ -116,8 +115,7 @@ def serve_stylesheet(stylesheet):
         Input('search-button', 'n_clicks'),
         Input('dropdown', 'value'),
         Input('query', 'value'),
-        Input('upload', 'contents'),
-        Input('write-button', 'n_clicks'),
+        Input('query', 'n_submit'),
     ],
     state=[State('store', 'data')],
     prevent_initial_call=True,
@@ -140,12 +138,18 @@ def on_event(*inputs):
     context = dash.callback_context
     store = context.states['store.data'] or {}  # type: dict
     trigger = context.triggered_id
-    value = context.triggered[0]['value']
     query = context.inputs['query.value']
     group_by_asset = context.inputs['dropdown.value'] == 'asset'
 
-    if trigger == 'init-button':
-        hst.request(store, EP.update, store.get('config', hb.config))
+    initial_query = context.inputs['query.n_submit'] == 0
+    ready = getattr(APP, 'ready', False)
+    if initial_query and not ready:
+        APP.ready = True
+        raise PreventUpdate
+
+    if trigger == 'workflow-button':
+        hst.request(store, EP.workflow, dict(steps=hb.config['workflow']))
+        store = hst.search(store, query, group_by_asset)
 
     elif trigger == 'update-button':
         hst.request(store, EP.update)
@@ -160,29 +164,9 @@ def on_event(*inputs):
     elif trigger == 'delete-button':
         hst.request(store, EP.delete)
 
-    elif trigger == 'search-button':
-        store = hst.search(store, query, group_by_asset)
-
-    elif trigger == 'upload':
-        temp = 'invalid'  # type: Any
-        try:
-            temp = hst.parse_json_file_content(value)
-            Config(temp).validate()
-            store['config'] = temp
-            store['config_error'] = None
-        except Exception as error:
-            store['config'] = temp
-            store['config_error'] = hst.error_to_response(error).json()  # type: ignore
-
-    # elif input_id == 'write-button':
-    #     try:
-    #         config = store['config']
-    #         Config(config).validate()
-    #         with open(CONFIG_PATH, 'w') as f:  # type: ignore
-    #             json.dump(config, f, indent=4, sort_keys=True)
-    #         store['config_error'] = None
-    #     except Exception as error:
-    #         store['config_error'] = hst.error_to_response(error).json
+    elif trigger in ['search-button', 'query']:
+        if store.get('ready', False):
+            store = hst.search(store, query, group_by_asset)
 
     return store
 
@@ -220,7 +204,7 @@ def on_datatable_update(store):
 @APP.callback(
     Output('content', 'children'),
     [Input('tabs', 'value')],
-    [State('store', 'data')]
+    [State('store', 'data')],
 )
 def on_get_tab(tab, store):
     # type: (str, Dict) -> Union[flask.Response, List, None]
@@ -254,10 +238,17 @@ def on_get_tab(tab, store):
             return components.get_key_value_card(
                 data, header='error', id_='error'
             )
-        return components.get_asset_graph(data['response'])
+        graph = data['response']
+        if len(graph) == 0:
+            return None
+        return components.get_asset_graph(graph)
 
     elif tab == 'config':
-        config = store.get('config', hb.config)
+        config = hst.format_config(
+            hb.config,
+            redact_regex=hb.config['redact_regex'],
+            redact_hash=hb.config['redact_hash'],
+        )
         return components.get_config_tab(config)
 
     elif tab == 'api':
@@ -270,49 +261,6 @@ def on_get_tab(tab, store):
         )
 
 
-@APP.callback(
-    Output('config-content', 'children'),
-    [Input('store', 'modified_timestamp')],
-    [State('store', 'data')]
-)
-def on_config_card_update(timestamp, store):
-    # type: (int, Dict[str, Any]) -> flask.Response
-    '''
-    Updates config card with config information from store.
-
-    Args:
-        timestamp (int): Store modification timestamp.
-        store (dict): Store data.
-
-    Returns:
-        flask.Response: Response.
-    '''
-    if store in [{}, None]:
-        raise PreventUpdate
-
-    config = store.get('config', None)
-    if config is None:
-        raise PreventUpdate
-
-    if config == 'invalid':
-        config = {}
-
-    error = store.get('config_error', None)
-
-    output = components.get_key_value_card(config, 'config', 'config-card')
-    if error is not None:
-        output = [
-            output,
-            html.Div(className='row-spacer'),
-            components.get_key_value_card(error, 'error', 'error')
-        ]
-
-    msg = 'on_config_card_update called with'
-    msg += f'config: {config} and error: {str(error)[:50]}'
-    APP.logger.debug(msg)
-    return output
-
-
 @APP.callback(
     Output('progressbar-container', 'children'),
     [Input('clock', 'n_intervals')],
