@@ -1,5 +1,6 @@
-from typing import Any, Dict, List, Optional
+from typing import Any, Dict, List, Optional, Union
 
+from collections import OrderedDict
 import re
 
 from dash import dash_table, dcc, html
@@ -210,12 +211,13 @@ def get_searchbar(query=None):
         placeholder='SQL query that uses "FROM data"',
         type='text',
         autoFocus=True,
-        debounce=True
+        debounce=True,
+        n_submit=0,
     )
     dropdown = get_dropdown(['asset', 'file'])
 
     search = get_button('search')
-    init = get_button('init')
+    workflow = get_button('workflow')
     update = get_button('update')
     create = get_button('create')
     export = get_button('export')
@@ -230,7 +232,7 @@ def get_searchbar(query=None):
             spacer,
             dropdown,
             spacer,
-            init,
+            workflow,
             spacer,
             update,
             spacer,
@@ -262,13 +264,11 @@ def get_dummy_elements():
         dcc.Input(className='dummy', id='query', value=None),
         dcc.Dropdown(className='dummy', id='dropdown', value=None),
         html.Div(className='dummy', id='search-button', n_clicks=None),
-        html.Div(className='dummy', id='init-button', n_clicks=None),
+        html.Div(className='dummy', id='workflow-button', n_clicks=None),
         html.Div(className='dummy', id='update-button', n_clicks=None),
         html.Div(className='dummy', id='create-button', n_clicks=None),
         html.Div(className='dummy', id='export-button', n_clicks=None),
         html.Div(className='dummy', id='delete-button', n_clicks=None),
-        dcc.Upload(className='dummy', id='upload', contents=None),
-        html.Div(className='dummy', id='write-button', n_clicks=None),
     ]
 
 
@@ -283,21 +283,7 @@ def get_configbar(config):
     Returns:
         Div: Div with buttons and JSON editor.
     '''
-    expander = html.Div(className='col expander')
-    spacer = html.Div(className='col spacer')
-
-    upload = dcc.Upload(
-        id='upload',
-        children=[get_button('upload')]
-    )
-    write = get_button('write')
-
     rows = [
-        html.Div(
-            className='row',
-            children=[expander, spacer, upload, spacer, write],
-        ),
-        html.Div(className='row-spacer'),
         html.Div(id='config', children=[
             get_key_value_card(config, header='config', id_='config-card')
         ])
@@ -400,8 +386,8 @@ def get_button(title):
     return html.Button(id=f'{title}-button', children=[title], n_clicks=0)
 
 
-def get_key_value_card(data, header=None, id_='key-value-card'):
-    # type: (Dict, Optional[str], str) -> html.Div
+def get_key_value_card(data, header=None, id_='key-value-card', sorting=False):
+    # type: (Union[Dict, OrderedDict], Optional[str], str, bool) -> html.Div
     '''
     Creates a key-value card using the keys and values from the given data.
     One key-value pair per row.
@@ -410,6 +396,8 @@ def get_key_value_card(data, header=None, id_='key-value-card'):
         data (dict): Dictionary to be represented.
         header (str, optional): Name of header. Default: None.
         id_ (str): Name of id property. Default: "key-value-card".
+        sorting (bool, optional): Whether to sort the output by key.
+            Default: False.
 
     Returns:
         Div: Card with key-value child elements.
@@ -429,7 +417,10 @@ def get_key_value_card(data, header=None, id_='key-value-card'):
         )
         children.append(header)
 
-    for i, (k, v) in enumerate(sorted(data.items())):
+    items = data.items()  # type: Any
+    if sorting:
+        items = sorted(items)
+    for i, (k, v) in enumerate(items):
         even = i % 2 == 0
         klass = 'odd'
         if even:
