@@ -4,11 +4,12 @@ from pathlib import Path
 import os
 
 import flask
-import jsoncomment as jsonc
+import pyjson5 as jsonc
 import yaml
 
 from hidebound.core.database import Database
 from hidebound.server.api import API
+import hidebound.core.config as hbc
 import hidebound.core.tools as hbt
 # ------------------------------------------------------------------------------
 
@@ -39,10 +40,14 @@ class HideboundExtension:
         '''
         config_path = os.environ.get('HIDEBOUND_CONFIG_FILEPATH', None)
         if config_path is not None:
-            return self._get_config_from_file(config_path)
+            config = self._get_config_from_file(config_path)
 
-        app.config.from_prefixed_env('HIDEBOUND')
-        return self._get_config_from_env(app)
+        else:
+            app.config.from_prefixed_env('HIDEBOUND')
+            config = self._get_config_from_env(app)
+
+        config = hbc.Config(config).to_native()
+        return config
 
     def _get_config_from_file(self, filepath):
         # type: (Union[str, Path]) -> dict
@@ -70,7 +75,7 @@ class HideboundExtension:
         with open(filepath) as f:
             if ext in ['yml', 'yaml']:
                 return yaml.safe_load(f)
-            return jsonc.JsonComment().load(f)
+            return jsonc.load(f)
 
     def _get_config_from_env(self, app):
         # type: (flask.Flask) -> dict
@@ -89,11 +94,17 @@ class HideboundExtension:
             include_regex=app.config.get('INCLUDE_REGEX', ''),
             exclude_regex=app.config.get('EXCLUDE_REGEX', r'\.DS_Store'),
             write_mode=app.config.get('WRITE_MODE', 'copy'),
-            dask_enabled=hbt.str_to_bool(app.config.get('DASK_ENABLED', 'False')),
             dask_workers=int(app.config.get('DASK_WORKERS', 8)),
+            dask_cluster_type=app.config.get('DASK_CLUSTER_TYPE', 'local'),
+            redact_regex=app.config.get('REDACT_REGEX', '(_key|_id|url)$'),
+            redact_hash=hbt.str_to_bool(app.config.get('REDACT_HASH', 'False')),
             specification_files=yaml.safe_load(
                 str(app.config.get('SPECIFICATION_FILES', '[]'))
             ),
+            workflow=yaml.safe_load(str(app.config.get(
+                'WORKFLOW',
+                '["delete", "update", "create", "export"]',
+            ))),
             exporters=yaml.safe_load(str(app.config.get('EXPORTERS', '{}'))),
             webhooks=yaml.safe_load(str(app.config.get('WEBHOOKS', '[]'))),
         )
