@@ -1,11 +1,13 @@
 from typing import Any, Dict, Optional, Union
 
+from collections import OrderedDict
 from dataclasses import dataclass
 from pathlib import Path
 from pprint import pformat
 import base64
 import json
 import os
+import re
 import traceback
 
 from flask.testing import FlaskClient
@@ -13,6 +15,8 @@ import flask
 import jinja2
 import lunchbox.tools as lbt
 import requests
+import rolling_pin.blob_etl as rpb
+import yaml
 
 import hidebound.core.logging as hblog
 # ------------------------------------------------------------------------------
@@ -37,6 +41,7 @@ class EndPoints:
     delete = f'http://{HOST}:{PORT}/api/delete'
     read = f'http://{HOST}:{PORT}/api/read'
     search = f'http://{HOST}:{PORT}/api/search'
+    workflow = f'http://{HOST}:{PORT}/api/workflow'
     progress = f'http://{HOST}:{PORT}/api/progress'
 # ------------------------------------------------------------------------------
 
@@ -265,6 +270,7 @@ def request(store, url, params=None, client=requests):
         response = response.json()  # pragma: no cover
     if code < 200 or code >= 300:
         store['content'] = response
+    store['ready'] = True
     return response
 
 
@@ -285,4 +291,61 @@ def search(store, query, group_by_asset, client=requests):
     params = dict(query=query, group_by_asset=group_by_asset)
     store['content'] = request(store, EndPoints().search, params, client)
     store['query'] = query
+    store['ready'] = True
     return store
+
+
+def format_config(
+    config, redact_regex='(_key|_id|url)$', redact_hash=False
+):
+    # type: (Dict[str, Any], str, bool) -> OrderedDict[str, Any]
+    '''
+    Redacts credentials of config and formats it for display in component.
+
+    Args:
+        config (dict): Configuration dictionary.
+        redact_regex (str, optional): Regular expression that matches keys,
+            whose values are to be redacted. Default: "(_key|_id|url)$".
+        redact_hash (bool, optional): Whether to redact values with the string
+            "REDACTED" or a hash of the value. Default: False.
+
+    Returns:
+        OrderedDict: Formatted config.
+    '''
+    def redact(key, value, as_hash):
+        if as_hash:
+            return 'hash-' + str(hash(value)).lstrip('-')
+        return 'REDACTED'
+
+    def predicate(key, value):
+        if re.search(redact_regex, key):
+            return True
+        return False
+
+    config = rpb.BlobETL(config) \
+        .set(predicate, value_setter=lambda k, v: redact(k, v, redact_hash)) \
+        .to_dict()
+    output = OrderedDict()
+    keys = [
+        'ingress_directory',
+        'staging_directory',
+        'include_regex',
+        'exclude_regex',
+        'write_mode',
+        'dask_workers',
+        'dask_cluster_type',
+        'redact_regex',
+        'redact_hash',
+        'specification_files',
+        'workflow',
+        'exporters',
+        'webhooks',
+    ]
+    all_ = set(config.keys())
+    cross = all_.intersection(keys)
+    diff = sorted(list(all_.difference(cross)))
+    keys = list(filter(lambda x: x in cross, keys)) + diff
+    for key in keys:
+        val = re.sub(r'\.\.\.$', '', yaml.safe_dump(config[key])).rstrip('\n')
+        output[key] = val
+    return output
